#######################################################################
# This file is part of steve.
#
# Copyright (C) 2012-2014 Will Kahn-Greene
# Licensed under the Simplified BSD License. See LICENSE for full
# license.
#######################################################################

# See http://www.python.org/dev/peps/pep-0386/
# Examples:
# * 1.0.dev
# * 1.0a2
# * 1.0b2
# * 1.0
__version__ = '0.3'
__releasedate__ = '2014-03-17'
